import java.util.Scanner;
import java.io.File;
import java.io.FileNotFoundException;
import java.util.ArrayList;

/**
 * Clase encargada de convertir el texto en un programa entendible por la maquina
 */
abstract class Compiler{

/**
 * Metodo estatico que se encarga de hacer la lista de estados de la maquina
 * @param in Objeto de tipo scanner que conteiene el texto a compilar
 * @return La lista de estados
 */
    public static ArrayList<State> States(Scanner in) {
        ArrayList<State> states = new ArrayList<State>();
        Scanner split;
        String line, segment, name, value, symbol, movement, next_state;
        name = "";
        ArrayList<Instruction> instructions = new ArrayList<Instruction>();
        line=in.nextLine().trim();
        while(line.length()!=0) {
            split = new Scanner(line).useDelimiter(",");
            segment=split.next();

            if (!split.hasNext()) {
                if (name!="") {
                    states.add(new State(name, instructions));
                }
                instructions.clear();
                name = segment;
            }
            else {
                value = segment;
                segment = split.next();
                symbol = segment;
                segment = split.next();
                movement = segment;
                segment = split.next();
                next_state = segment;
                instructions.add(new Instruction(value,symbol,movement,next_state));
            }
            line=in.nextLine().trim();

        }
        states.add(new State(name, instructions));

        return states;
    }

/**
 * Metodo estatico que se encarga encontrar el estado inicial de la maquina
 * @param in Objeto de tipo scanner que conteiene el texto a compilar
 * @return El estado inicial de la maquina
 */
    public static String InitialState(Scanner in) {
        return in.nextLine().trim();
    }

/**
 * Metodo estatico que se encarga de hacer la lista de 
 * estados aceptados por la maquina al finalizar su ejecucion
 * @param in Objeto de tipo scanner que conteiene el texto a compilar
 * @return states La lista de estados
 */
    public static ArrayList<String> AcceptingStates(Scanner in) {
        ArrayList<String> states = new ArrayList();
        String line, segment;
        line=in.nextLine().trim();

        Scanner split = new Scanner(line).useDelimiter(",");
        while (split.hasNext()){
            segment=split.next().trim();
            states.add(segment);
        }
        return states;
    }
}