/**
 * Instruccion contenida en un estado de la maquina
 * Contiene lo que se debe hacer dependiendo del simbolo leido
 */
class Instruction{

/**
 * Constructor de la instruccion
 * @param v Valor de la celda leida por el cabezal
 * @param s Simbolo a escribir en la cinta
 * @param m Direccion en la que se debera mover el cabezal
 * @param n Siguiente estado que adoptara la maquina
 */
	public Instruction(String v, String s, String m, String n){
        value = v;
        symbol = s;
        movement = m;
        next_state = n;
	}

/**
 * Entrega el valor de la celda que lee el cabezal
 * @return Valor de la celda
 */
    public String GetValue(){
        return value;
    }

/**
 * Entrega el simbolo a escribir
 * @return Simbolo a escribir
 */
    public String GetSymbol(){
        return symbol;
    }

/**
 * Entrega el movimiento que debe hacer el cabezal
 * @return Movimiento
 */
    public String GetMovement(){
        return movement;
    }

/**
 * Entrega el siguiente estado que debe adoptar el  cabezal
 * @return Nombre del siguiente estado
 */
    public String GetNextState(){
        return next_state;
    }

/**
 * Transforma la instruccion en un string
 * @return Instruccion como string
 */
    public String toString() {
        String s = "";
        s+=value;
        s+=";";
        s+=symbol;
        s+=";";
        s+=movement;
        s+=";";
        s+=next_state;
        return s;
    }

	private String value;
	private String symbol;
	private String movement;
	private String next_state;
}